@@ -57,7 +57,7 @@
 /* #undef HAVE_HALIDE */
 
 /* Vulkan support */
-/* #undef HAVE_VULKAN */
+#define HAVE_VULKAN
 
 /* Define to 1 if you have the <inttypes.h> header file. */
 /* #undef HAVE_INTTYPES_H */
@@ -76,7 +76,10 @@
 /* #undef HAVE_AVIF */
 
 /* IJG JPEG codec */
-/* #undef HAVE_JPEG */
+#define HAVE_JPEG
+
+/* JPEG XL codec */
+/* #undef HAVE_JPEGXL */
 
 /* GDCM DICOM codec */
 /* #undef HAVE_GDCM */
@@ -101,10 +104,10 @@
 /* #undef HAVE_OPENEXR */
 
 /* OpenGL support*/
-/* #undef HAVE_OPENGL */
+#define HAVE_OPENGL
 
 /* PNG codec */
-/* #undef HAVE_PNG */
+#define HAVE_PNG
 
 /* PNG codec */
 /* #undef HAVE_SPNG */
@@ -122,7 +125,7 @@
 /* #undef HAVE_HPX */
 
 /* TIFF codec */
-/* #undef HAVE_TIFF */
+#define HAVE_TIFF
 
 /* Define if your processor stores words with the most significant byte
    first (like Motorola and SPARC, unlike Intel and VAX). */
